@@ -7,7 +7,7 @@ from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import (
 from opentelemetry.exporter.otlp.proto.http.metric_exporter import (
     OTLPMetricExporter as HTTPExporter,
 )
-from opentelemetry.semconv.ai import Meters
+from opentelemetry.semconv_ai import Meters
 from opentelemetry.sdk.metrics import MeterProvider
 from opentelemetry.sdk.metrics.export import (
     PeriodicExportingMetricReader,
@@ -88,27 +88,6 @@ def metric_views() -> Sequence[View]:
     return [
         View(
             instrument_name=Meters.LLM_TOKEN_USAGE,
-            aggregation=ExplicitBucketHistogramAggregation(
-                [
-                    0.01,
-                    0.02,
-                    0.04,
-                    0.08,
-                    0.16,
-                    0.32,
-                    0.64,
-                    1.28,
-                    2.56,
-                    5.12,
-                    10.24,
-                    20.48,
-                    40.96,
-                    81.92,
-                ]
-            ),
-        ),
-        View(
-            instrument_name=Meters.LLM_OPERATION_DURATION,
             aggregation=ExplicitBucketHistogramAggregation(
                 [
                     1,
